Projects using multigtfs
========================

Projects using multigtfs include:

* `GTFS Explorer`_ - A web application from `MRCagney`_ to analyze and
  visualize public transport data.
* `tulsa-transit-google`_ - The original project that spawned multigtfs.
  Tulsa Transit no longer uses this code, but instead is using the GTFS export
  feature of their scheduling provider.

Want to see your project here?  Send a `pull request`_ or `open an issue`_.

.. _`GTFS Explorer`: https://gtfs-explorer.mrcagney.works
.. _`MRCagney`: http://mrcagney.com
.. _`tulsa-transit-google`: https://github.com/tulsawebdevs/tulsa-transit-google
.. _`pull request`: contributors.html
.. _`open an issue`: https://github.com/tulsawebdevs/django-multi-gtfs/issues?state=open
